==> davical_0.9.9.4.orig.tar.gz: davical-0.9.9.4.orig/dba/supported_locales.sql <==
TRUNCATE supported_locales;

INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'en_EN', 'English', 'English' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'de_DE', 'German',  'Deutsch' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'es_ES', 'Spanish', 'Español' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'fr_FR', 'French',  'Français' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'ru_RU', 'Russian',  'Русский' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'nl_NL', 'Netherlands',  'Nederlands' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'pl_PL', 'Polish',  'Polski' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'hu_HU', 'Hungarian',  'Magyar' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'ja_JP', 'Japanese',  '日本語' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'it_IT', 'Italian',  'Italiano' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'sv_SE', 'Swedish',  'Svenska' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'et_EE', 'Estonian',  'Eesti' );

==> davical_0.9.9.7-1.tar.gz: davical-0.9.9.7/dba/supported_locales.sql <==
TRUNCATE supported_locales;
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'en', 'English', 'English' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'de', 'German',  'Deutsch' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
  VALUES( 'es_AR', 'Spanish (Argentina)', 'Español (Argentina)' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
  VALUES( 'es_MX', 'Spanish (Mexico)', 'Español (Mexico)' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'es_VE', 'Spanish (Venezuela)', 'Español (Venezuela)' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'et', 'Estonian',  'Eesti' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'fr', 'French',  'Français' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'hu', 'Hungarian',  'Magyar' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'it', 'Italian',  'Italiano' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'ja', 'Japanese',  '日本語' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'nb', 'Norwegian',  'Bokmål' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'nl', 'Netherlands',  'Nederlands' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'pl', 'Polish',  'Polski' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'pt_BR', 'Brazilian Portuguese',  'Brazilian Portuguese' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'pt_PT', 'Portuguese',  'Portuguese' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'ru', 'Russian',  'Русский' );
INSERT INTO supported_locales ( locale, locale_name_en, locale_name_locale )
    VALUES( 'sv', 'Swedish',  'Svenska' );
